==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GatewayRouteSpecHttpRouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property hostname Host name to rewrite.
 * @property path Exact path to rewrite.
 * @property prefix Specified beginning characters to rewrite.
 */
public data class GatewayRouteSpecHttpRouteActionRewrite(
    public val hostname: GatewayRouteSpecHttpRouteActionRewriteHostname? = null,
    public val path: GatewayRouteSpecHttpRouteActionRewritePath? = null,
    public val prefix: GatewayRouteSpecHttpRouteActionRewritePrefix? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GatewayRouteSpecHttpRouteActionRewrite):
            GatewayRouteSpecHttpRouteActionRewrite = GatewayRouteSpecHttpRouteActionRewrite(
            hostname = javaType.hostname().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttpRouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }).orElse(null),
            path = javaType.path().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttpRouteActionRewritePath.Companion.toKotlin(args0)
                })
            }).orElse(null),
            prefix = javaType.prefix().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttpRouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GatewayRouteSpecHttpRouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property hostname Host name to rewrite.
 * @property path Exact path to rewrite.
 * @property prefix Specified beginning characters to rewrite.
 */
public data class GatewayRouteSpecHttpRouteActionRewrite(
    public val hostname: GatewayRouteSpecHttpRouteActionRewriteHostname? = null,
    public val path: GatewayRouteSpecHttpRouteActionRewritePath? = null,
    public val prefix: GatewayRouteSpecHttpRouteActionRewritePrefix? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GatewayRouteSpecHttpRouteActionRewrite): GatewayRouteSpecHttpRouteActionRewrite = GatewayRouteSpecHttpRouteActionRewrite(
            hostname = javaType.hostname().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttpRouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }).orElse(null),
            path = javaType.path().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttpRouteActionRewritePath.Companion.toKotlin(args0)
                })
            }).orElse(null),
            prefix = javaType.prefix().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GatewayRouteSpecHttpRouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
